"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const build_helper_service_1 = require("./../services/build-helper.service");
const exec_tool_1 = require("../utils/exec.tool");
const colors_1 = __importDefault(require("colors"));
class BuildControl {
    constructor() {
        this.buildHelper = new build_helper_service_1.BuildHelperService();
        this.buildExec = new exec_tool_1.ExecTool(`npm run build`);
        this.buildCdnExec = new exec_tool_1.ExecTool(`npm run cross-env`);
    }
    init(env, addMessage) {
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            const create = yield this.buildHelper.createEnvFile(env);
            if (!create.status) {
                resolve(create);
            }
            else {
                const cdn = yield this.buildHelper.checkCdn(env);
                if (!cdn.status) {
                    const build = yield this.build(addMessage);
                    resolve(build);
                }
                else {
                    const buildcdn = yield this.buildCdn(addMessage, cdn.data);
                    resolve(buildcdn);
                }
            }
        }));
    }
    build(addMessage) {
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            const build = yield this.buildExec.run();
            if (!build.status) {
                resolve(build);
            }
            else {
                const remove = yield this.buildHelper.removeEnvFile();
                if (!remove.status) {
                    console.log(colors_1.default.yellow(`删除 .env.production 文件失败`));
                }
                if (addMessage) {
                    console.log(colors_1.default.cyan(`开始添加build信息到 index.html 文件`));
                    const add = yield this.buildHelper.addIndexMessage(addMessage);
                    if (!add.status) {
                        console.log(colors_1.default.yellow(`添加信息失败！`));
                    }
                    else {
                        console.log(colors_1.default.cyan(`添加信息: ${addMessage}`));
                    }
                }
                resolve({
                    status: true
                });
            }
        }));
    }
    buildCdn(addMessage, cdn) {
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            const crossEnv = yield this.buildHelper.checkCrossEnv(cdn);
            if (!crossEnv.status) {
                console.log(colors_1.default.red(`生成发布命令失败，请稍后重试`));
                console.log(colors_1.default.yellow(`请按照以下列表检查`));
                console.log(colors_1.default.yellow(`1、检查是否安装了cross-env依赖：npm install cross-env --save`));
                console.log(colors_1.default.yellow(`2、检查是否添加了cross-env任务：在package.json文件中添加 cross-env:"cross-env"`));
                console.log(colors_1.default.yellow(`3、检查cdn.helper.json文件完整性`));
                console.log(colors_1.default.yellow(`4、检查本地是否生成了package.json文件，且文件中添加了 cross-env:"cross-env" build命令`));
                console.log(``);
                resolve({ status: false });
            }
            else {
                const build = yield this.buildCdnExec.run();
                if (!build.status) {
                    resolve(build);
                }
                else {
                    const remove = yield this.buildHelper.removeEnvFile();
                    if (!remove.status) {
                        console.log(colors_1.default.yellow(`删除 .env.production 文件失败`));
                    }
                    if (addMessage) {
                        console.log(colors_1.default.cyan(`开始添加build信息到 index.html 文件`));
                        const add = yield this.buildHelper.addIndexMessage(addMessage);
                        if (!add.status) {
                            console.log(colors_1.default.yellow(`添加信息失败！`));
                        }
                        else {
                            console.log(colors_1.default.cyan(`添加信息: ${addMessage}`));
                        }
                    }
                    resolve({ status: true });
                }
            }
        }));
    }
}
exports.BuildControl = BuildControl;
