#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const build_controle_1 = require("./controllers/build.controle");
const commit_controle_1 = require("./controllers/commit.controle");
const create_helper_control_1 = require("./controllers/create-helper.control");
const program_1 = __importDefault(require("./program"));
const path_tool_1 = require("./utils/path.tool");
const init_control_1 = require("./controllers/init.control");
const git_start_controle_1 = require("./controllers/git-start.controle");
const git_end_control_1 = require("./controllers/git-end.control");
const upload_controle_1 = require("./controllers/upload.controle");
const pathTool = new path_tool_1.PathTool();
if (!program_1.default.args.length) {
    console.log(`args error，only support 'init、create、publish'`.red);
    program_1.default.help();
}
else {
    if (program_1.default.args[0] === 'init') {
        let cloneOrder = `git clone ${program_1.default.url}`;
        if (program_1.default.filename) {
            cloneOrder = cloneOrder + ` ${program_1.default.filename}`;
        }
        const execPath = pathTool.createPath(program_1.default.path);
        const init = new init_control_1.InitControl(cloneOrder, execPath);
        init.init();
    }
    if (program_1.default.args[0] === 'create') {
        const create = new create_helper_control_1.CreateHelperControl(program_1.default.type);
        create.init();
    }
    if (program_1.default.args[0] === 'build') {
        const commit = new commit_controle_1.CommitControl();
        const build = new build_controle_1.BuildControl();
        const run = (cb) => __awaiter(this, void 0, void 0, function* () {
            const commitres = yield commit.init(!program_1.default.autopatch || program_1.default.autopatch === 'false' ? false : true);
            let message = '';
            if (program_1.default.show) {
                if (program_1.default.message === 'commit') {
                    message = `message:${commitres.commit.message},date:${commitres.commit.date},hash:${commitres.commit
                        .commit}`;
                }
                else {
                    message = `version:${commitres.version ? commitres.version : '获取版本号失败'},message:${commitres.commit
                        .message},date:${commitres.commit.date},hash:${commitres.commit.commit}`;
                }
                message = message.replace(/"/g, '');
                message = message.replace(/'/g, '');
                message = message.replace(/\s/g, '');
            }
            const buildres = yield build.init(program_1.default.env, message);
        });
        run();
    }
    if (program_1.default.args[0] === 'push') {
        const gitstart = new git_start_controle_1.GitStartControl();
        const gitend = new git_end_control_1.GitEndControl();
        const run = () => __awaiter(this, void 0, void 0, function* () {
            const start = yield gitstart.init(program_1.default.env);
            if (start.status) {
                const commit = new commit_controle_1.CommitControl();
                const commitres = yield commit.init(!program_1.default.autopatch || program_1.default.autopatch === 'false' ? false : true);
                let message = '';
                if (program_1.default.show) {
                    if (program_1.default.message === 'commit') {
                        message = `message:${commitres.commit.message},date:${commitres.commit.date},hash:${commitres
                            .commit.commit}`;
                    }
                    else {
                        message = `version:${commitres.version ? commitres.version : '获取版本号失败'},message:${commitres
                            .commit.message},date:${commitres.commit.date},hash:${commitres.commit.commit}`;
                    }
                    message = message.replace(/"/g, '');
                    message = message.replace(/'/g, '');
                    message = message.replace(/\s/g, '');
                }
                const end = yield gitend.init(program_1.default.env, program_1.default.open === 'false' || !program_1.default.open ? false : true);
            }
        });
        run();
    }
    if (program_1.default.args[0] === 'upload') {
        const upload = new upload_controle_1.UploadControl();
        const run = (cb) => __awaiter(this, void 0, void 0, function* () {
            const uploader = yield upload.init(program_1.default.env);
        });
        run();
    }
    if (program_1.default.args[0] === 'publish') {
        const commit = new commit_controle_1.CommitControl();
        const build = new build_controle_1.BuildControl();
        const gitstart = new git_start_controle_1.GitStartControl();
        const gitend = new git_end_control_1.GitEndControl();
        const upload = new upload_controle_1.UploadControl();
        const run = (cb) => __awaiter(this, void 0, void 0, function* () {
            const commitres = yield commit.init(!program_1.default.autopatch || program_1.default.autopatch === 'false' ? false : true);
            let message = '';
            if (program_1.default.show) {
                if (program_1.default.message === 'commit') {
                    message = `message:${commitres.commit.message},date:${commitres.commit.date},hash:${commitres.commit
                        .commit}`;
                }
                else {
                    message = `version:${commitres.version ? commitres.version : '获取版本号失败'},message:${commitres.commit
                        .message},date:${commitres.commit.date},hash:${commitres.commit.commit}`;
                }
                message = message.replace(/"/g, '');
                message = message.replace(/'/g, '');
                message = message.replace(/\s/g, '');
            }
            const buildres = yield build.init(program_1.default.env, message);
            if (buildres.status) {
                const start = yield gitstart.init(program_1.default.env);
                if (start.status) {
                    const commit = new commit_controle_1.CommitControl();
                    const commitres = yield commit.init(!program_1.default.autopatch || program_1.default.autopatch === 'false' ? false : true);
                    let message = '';
                    if (program_1.default.show) {
                        if (program_1.default.message === 'commit') {
                            message = `message:${commitres.commit.message},date:${commitres.commit
                                .date},hash:${commitres.commit.commit}`;
                        }
                        else {
                            message = `version:${commitres.version ? commitres.version : '获取版本号失败'},message:${commitres
                                .commit.message},date:${commitres.commit.date},hash:${commitres.commit.commit}`;
                        }
                        message = message.replace(/"/g, '');
                        message = message.replace(/'/g, '');
                        message = message.replace(/\s/g, '');
                    }
                    const end = yield gitend.init(program_1.default.env, program_1.default.open === 'false' || !program_1.default.open ? false : true);
                    if (end.status) {
                        const uploader = yield upload.init(program_1.default.env);
                    }
                }
            }
        });
        run();
    }
}
