"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_tool_1 = require("./../utils/path.tool");
const file_tool_1 = require("./../utils/file.tool");
const exec_tool_1 = require("../utils/exec.tool");
const remove_helper_service_1 = require("./remove-helper.service");
const replace_in_file_1 = __importDefault(require("replace-in-file"));
const colors_1 = __importDefault(require("colors"));
class BuildHelperService {
    constructor() {
        this.buildFile = new file_tool_1.FileTool();
        this.pathTool = new path_tool_1.PathTool();
        this.installCrossEnv = new exec_tool_1.ExecTool(`npm install cross-env --save`);
        this.removeEnvFileTool = new remove_helper_service_1.RemoveHelperService(`.env.production`);
        this.removePushFileTool = new remove_helper_service_1.RemoveHelperService(`./push`, this.pathTool.createPath());
    }
    createEnvFile(env) {
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            const create = yield this.buildFile.write(`${this.pathTool.createPath()}/.env.production`, `REACT_APP_ENV=${env}`);
            resolve(create);
        }));
    }
    checkCrossEnv(cdn) {
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            const config = yield this.buildFile.read(`${this.pathTool.createPath()}/package.json`);
            if (!config.status) {
                resolve({ status: false });
            }
            else {
                if (!config.data.scripts[`cross-env`]) {
                    const install = yield this.installCrossEnv.run();
                    if (!install.status) {
                        resolve({ status: false });
                        return null;
                    }
                }
                const newconfig = yield this.buildFile.read(`${this.pathTool.createPath()}/package.json`);
                if (!newconfig.status) {
                    resolve(newconfig);
                }
                else {
                    newconfig.data.scripts[`cross-env`] = `cross-env PUBLIC_URL=${this.createPublicUrl(cdn)} node scripts/build.js`;
                    const writepackge = yield this.buildFile.write(`${this.pathTool.createPath()}/package.json`, config);
                    if (!writepackge.status) {
                        resolve({ status: false });
                    }
                    else {
                        resolve({ status: true });
                    }
                }
            }
        }));
    }
    removeEnvFile() {
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            const rmove = yield this.removeEnvFileTool.remove();
            resolve(rmove);
        }));
    }
    addIndexMessage(message) {
        return new Promise((resolev) => __awaiter(this, void 0, void 0, function* () {
            const add = yield replace_in_file_1.default({
                files: [`${this.pathTool.createPath()}/build/index.html`],
                from: (file) => new RegExp('</head>', 'g'),
                to: `<script>console.log('${message ? message : '添加调试信息失败'}')</script></head>`
            });
            resolev({
                status: true
            });
        }));
    }
    checkCdn(env) {
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            const config = yield this.buildFile.read(`${this.pathTool.createPath()}/cdn.helper.json`);
            if (!config.status) {
                resolve({ status: false });
            }
            else {
                if (!config.data[env]) {
                    resolve({ status: false });
                }
                else {
                    const zones = ['z0', 'z1', 'z2', 'na0', 'as0'];
                    if (config.data[env].zone) {
                        if (zones.indexOf(config.data[env].zone) === -1) {
                            console.log(colors_1.default.yellow(`cdn配置项中zone值 ${config.data[env].zone} 不合法，暂时只支持 ${zones.join('，')}`));
                            config.data[env].zone = null;
                        }
                    }
                    resolve({
                        status: config.data[env].url && config.data[env].ak && config.data[env].sk && config.data[env].bk
                            ? true
                            : false,
                        data: config.data[env]
                    });
                }
            }
        }));
    }
    checkGithub(env) {
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            const config = yield this.buildFile.read(`${this.pathTool.createPath()}/github.helper.json`);
            if (!config.status) {
                resolve({ status: false });
            }
            else {
                if (!config.data[env]) {
                    resolve({ status: false });
                }
                else {
                    resolve({
                        status: config.data[env].remote && config.data[env].branch ? true : false,
                        data: config.data[env]
                    });
                }
            }
        }));
    }
    clonePushGit(url, branch) {
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            const cloneExec = new exec_tool_1.ExecTool(`git clone ${url} push -b ${branch}`);
            const clone = yield cloneExec.run();
            resolve(clone);
        }));
    }
    cleanPush(path, folder) {
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            const cleanExec = new exec_tool_1.ExecTool(folder ? `rm -rf ./${folder}` : `find ./push -name "*.js" -o -name "*.css" -o -name "*.html"`, path);
            const clean = yield cleanExec.run();
            resolve(clean);
        }));
    }
    copyPush(folder) {
        /* 由于git操作切到了push目录，复制类操作需要切回到项目根目录 */
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            const copyExec = new exec_tool_1.ExecTool(folder ? `cp -rf ./build ./push/${folder}/` : `cp -rf ./build ./push/`, this.pathTool.createPath('../'));
            const copy = yield copyExec.run();
            resolve(copy);
        }));
    }
    addPush(path) {
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            const addExec = new exec_tool_1.ExecTool(`git add -A`, path);
            const add = yield addExec.run();
            resolve(add);
        }));
    }
    ignorePush(ignores) {
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            let ignore = ``;
            ignores.forEach((item) => {
                ignore = `${ignore},${item}`;
            });
            if (ignore) {
                const addIgnore = yield this.buildFile.write(`${this.pathTool.createPath()}/push/.gitignore`, ignore);
                resolve(addIgnore);
            }
            else {
                resolve({ status: true });
            }
        }));
    }
    commitPush(path, message) {
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            const commitExec = new exec_tool_1.ExecTool(`git commit -m "${message ? message : JSON.stringify(new Date())}"`, path);
            const commit = yield commitExec.run();
            resolve(commit);
        }));
    }
    donePush(path, branch) {
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            const doneExec = new exec_tool_1.ExecTool(`git push origin ${branch}`, path);
            const done = yield doneExec.run();
            resolve(done);
        }));
    }
    removePush() {
        return new Promise((resolve) => __awaiter(this, void 0, void 0, function* () {
            const remove = yield this.removePushFileTool.remove();
            resolve(remove);
        }));
    }
    createPublicUrl(cdn) {
        let url = cdn.url ? cdn.url : './';
        if (cdn.dirname) {
            url = url + `${cdn.dirname}/`;
        }
        if (cdn.v) {
            url = url + `${cdn.v}/`;
        }
        return url;
    }
}
exports.BuildHelperService = BuildHelperService;
