import { BuildHelperService } from './../services/build-helper.service';
import { ExecTool } from '../utils/exec.tool';
import colors from 'colors';

export class BuildControl {
    private buildHelper: BuildHelperService = new BuildHelperService();
    private buildExec: ExecTool = new ExecTool(`npm run build`);
    private buildCdnExec: ExecTool = new ExecTool(`npm run cross-env`);
    constructor() {}
    public init(env: string, addMessage: string): Promise<any> {
        return new Promise(async (resolve) => {
            const create = await this.buildHelper.createEnvFile(env);
            if (!create.status) {
                resolve(create);
            } else {
                const cdn = await this.buildHelper.checkCdn(env);
                if (!cdn.status) {
                    const build = await this.build(addMessage);
                    resolve(build);
                } else {
                    const buildcdn = await this.buildCdn(addMessage, cdn.data);
                    resolve(buildcdn);
                }
            }
        });
    }
    private build(addMessage: string): Promise<any> {
        return new Promise(async (resolve) => {
            const build = await this.buildExec.run();
            if (!build.status) {
                resolve(build);
            } else {
                const remove = await this.buildHelper.removeEnvFile();
                if (!remove.status) {
                    console.log(colors.yellow(`删除 .env.production 文件失败`));
                }
                if (addMessage) {
                    console.log(colors.cyan(`开始添加build信息到 index.html 文件`));
                    const add = await this.buildHelper.addIndexMessage(addMessage);
                    if (!add.status) {
                        console.log(colors.yellow(`添加信息失败！`));
                    } else {
                        console.log(colors.cyan(`添加信息: ${addMessage}`));
                    }
                }
                resolve({
                    status: true
                });
            }
        });
    }
    private buildCdn(addMessage: string, cdn: any): Promise<any> {
        return new Promise(async (resolve) => {
            const crossEnv = await this.buildHelper.checkCrossEnv(cdn);
            if (!crossEnv.status) {
                console.log(colors.red(`生成发布命令失败，请稍后重试`));
                console.log(colors.yellow(`请按照以下列表检查`));
                console.log(colors.yellow(`1、检查是否安装了cross-env依赖：npm install cross-env --save`));
                console.log(colors.yellow(`2、检查是否添加了cross-env任务：在package.json文件中添加 cross-env:"cross-env"`));
                console.log(colors.yellow(`3、检查cdn.helper.json文件完整性`));
                console.log(colors.yellow(`4、检查本地是否生成了package.json文件，且文件中添加了 cross-env:"cross-env" build命令`));
                console.log(``);
                resolve({ status: false });
            } else {
                const build = await this.buildCdnExec.run();
                if (!build.status) {
                    resolve(build);
                } else {
                    const remove = await this.buildHelper.removeEnvFile();
                    if (!remove.status) {
                        console.log(colors.yellow(`删除 .env.production 文件失败`));
                    }
                    if (addMessage) {
                        console.log(colors.cyan(`开始添加build信息到 index.html 文件`));
                        const add = await this.buildHelper.addIndexMessage(addMessage);
                        if (!add.status) {
                            console.log(colors.yellow(`添加信息失败！`));
                        } else {
                            console.log(colors.cyan(`添加信息: ${addMessage}`));
                        }
                    }
                    resolve({ status: true });
                }
            }
        });
    }
}
