import { PathTool } from './../utils/path.tool';
import { BuildHelperService } from './../services/build-helper.service';
import colors from 'colors';
import open from 'open';

export class GitEndControl {
    private buildHelper: BuildHelperService = new BuildHelperService();
    private pathTool: PathTool = new PathTool();
    constructor() {}
    public init(env: string, open?: boolean): Promise<any> {
        return new Promise(async (resolve) => {
            const config = await this.buildHelper.checkGithub(env);
            if (config.status) {
                const clean = await this.buildHelper.cleanPush(
                    this.pathTool.createPath('./push/'),
                    config.data.dirname ? config.data.dirname : ''
                );
                if (clean.status) {
                    const copy = await this.buildHelper.copyPush(config.data.dirname ? config.data.dirname : '');
                    if (copy.status) {
                        const add = await this.buildHelper.addPush(this.pathTool.createPath('./push/'));
                        if (add.status) {
                            const commit = await this.buildHelper.commitPush(this.pathTool.createPath());
                            if (commit.status) {
                                const push = await this.buildHelper.donePush(
                                    this.pathTool.createPath(),
                                    config.data.branch
                                );
                                if (push.status) {
                                    const remove = await this.buildHelper.removePush();
                                    if (!remove.status) {
                                        console.log(colors.yellow(`删除push目录失败，请稍后手动删除`));
                                        console.log(``);
                                    }
                                    if (open) {
                                        this.open(config.data.remote);
                                    }
                                    resolve({ status: true });
                                } else {
                                    resolve({ status: false });
                                }
                            } else {
                                resolve({ status: false });
                            }
                        } else {
                            resolve({ status: false });
                        }
                    } else {
                        resolve({ status: false });
                    }
                } else {
                    resolve({ status: false });
                }
            } else {
                console.log(colors.red(`获取 ${env} 配置失败，请检查github.helper.json文件`));
                resolve({ status: false });
            }
        });
    }
    private open(remote: string) {
        let url;
        if (remote.indexOf('http') > -1) {
            url = remote.replace('http', 'https');
            url = url.replace('httpss', 'https');
            url = url.replace('.git', '');
        } else {
            if (remote.indexOf('git@ssh-') > -1) {
                /* gitlab */
                url = remote.replace(':', '/');
                url = url.replace('git@ssh-', 'https://');
                url = url.replace('.git', '');
            } else {
                /* github */
                url = remote.replace(':', '/');
                url = url.replace('git@', 'https://');
                url = url.replace('.git', '');
            }
        }
        if (url) {
            console.log(`打开发布地址: ${url}`.green);
            open(url);
        } else {
            console.log(`打开发布地址失败: ${remote}`.red);
        }
    }
}
