import { ExecTool } from './../utils/exec.tool';
import colors from 'colors';

export class InitControl {
    private cloneExec: ExecTool;
    private removeExec: ExecTool | any;
    private installExec: ExecTool;
    private fileName: string;
    constructor(cloneOrder: string, execPath: string) {
        this.cloneExec = new ExecTool(cloneOrder, execPath);
        this.fileName = this.getFileName(cloneOrder);
        if (cloneOrder.indexOf(`https://gitlab.jpushoa.com/front-end/ad-frontend-base-react`) > -1) {
            this.removeExec = new ExecTool(`rm -rf .git`, execPath + `/${this.fileName}`);
        } else {
            console.log(colors.yellow(`完成init任务后，可能需要在 ${this.fileName} 目录下手动执行 rm -rf .git 删除git仓库！`));
        }
        this.installExec = new ExecTool(`npm install`, execPath + `/${this.fileName}`);
    }
    public async init() {
        const clone = await this.cloneExec.run();
        if (clone.status) {
            if (this.removeExec) {
                const remove = await this.removeExec.run();
            }
            const install = await this.installExec.run();
            console.log(colors.yellow(`初始化任务执行完毕，请执行 cd ${this.fileName}/ 进入工程目录`));
        }
    }
    private getFileName(cloneOrder: string): string {
        const names = cloneOrder.split('/');
        if (cloneOrder.indexOf('.git') > -1) {
            const regValue = cloneOrder.match(/\.git(.*)/);
            if (!regValue) {
                return names[names.length - 1].replace('.git', '');
            }
            if (!regValue[1]) {
                return names[names.length - 1].replace('.git', '');
            }
            if (regValue[1]) {
                return regValue[1].replace(' ', '');
            }
        }
        return names[names.length - 1].split(' ')[1];
    }
}
