#!/usr/bin/env node

import { BuildControl } from './controllers/build.controle';
import { CommitControl } from './controllers/commit.controle';
import { CreateHelperControl } from './controllers/create-helper.control';
import program from './program';
import { PathTool } from './utils/path.tool';
import { InitControl } from './controllers/init.control';
import { GitStartControl } from './controllers/git-start.controle';
import { GitEndControl } from './controllers/git-end.control';
import { UploadControl } from './controllers/upload.controle';
const pathTool = new PathTool();

if (!program.args.length) {
    console.log(`args error，only support 'init、create、publish'`.red);
    program.help();
} else {
    if (program.args[0] === 'init') {
        let cloneOrder = `git clone ${program.url}`;
        if (program.filename) {
            cloneOrder = cloneOrder + ` ${program.filename}`;
        }
        const execPath = pathTool.createPath(program.path);
        const init = new InitControl(cloneOrder, execPath);
        init.init();
    }
    if (program.args[0] === 'create') {
        const create = new CreateHelperControl(program.type);
        create.init();
    }
    if (program.args[0] === 'build') {
        const commit = new CommitControl();
        const build = new BuildControl();
        const run = async (cb: void) => {
            const commitres = await commit.init(!program.autopatch || program.autopatch === 'false' ? false : true);
            let message = '';
            if (program.show) {
                if (program.message === 'commit') {
                    message = `message:${commitres.commit.message},date:${commitres.commit.date},hash:${commitres.commit
                        .commit}`;
                } else {
                    message = `version:${commitres.version ? commitres.version : '获取版本号失败'},message:${commitres.commit
                        .message},date:${commitres.commit.date},hash:${commitres.commit.commit}`;
                }
                message = message.replace(/"/g, '');
                message = message.replace(/'/g, '');
                message = message.replace(/\s/g, '');
            }
            const buildres = await build.init(program.env, message);
        };
        run();
    }
    if (program.args[0] === 'push') {
        const gitstart = new GitStartControl();
        const gitend = new GitEndControl();
        const run = async () => {
            const start = await gitstart.init(program.env);
            if (start.status) {
                const commit = new CommitControl();
                const commitres = await commit.init(!program.autopatch || program.autopatch === 'false' ? false : true);
                let message = '';
                if (program.show) {
                    if (program.message === 'commit') {
                        message = `message:${commitres.commit.message},date:${commitres.commit.date},hash:${commitres
                            .commit.commit}`;
                    } else {
                        message = `version:${commitres.version ? commitres.version : '获取版本号失败'},message:${commitres
                            .commit.message},date:${commitres.commit.date},hash:${commitres.commit.commit}`;
                    }
                    message = message.replace(/"/g, '');
                    message = message.replace(/'/g, '');
                    message = message.replace(/\s/g, '');
                }
                const end = await gitend.init(program.env, program.open === 'false' || !program.open ? false : true);
            }
        };
        run();
    }
    if (program.args[0] === 'upload') {
        const upload = new UploadControl();
        const run = async (cb: void) => {
            const uploader = await upload.init(program.env);
        };
        run();
    }
    if (program.args[0] === 'publish') {
        const commit = new CommitControl();
        const build = new BuildControl();
        const gitstart = new GitStartControl();
        const gitend = new GitEndControl();
        const upload = new UploadControl();
        const run = async (cb: void) => {
            const commitres = await commit.init(!program.autopatch || program.autopatch === 'false' ? false : true);
            let message = '';
            if (program.show) {
                if (program.message === 'commit') {
                    message = `message:${commitres.commit.message},date:${commitres.commit.date},hash:${commitres.commit
                        .commit}`;
                } else {
                    message = `version:${commitres.version ? commitres.version : '获取版本号失败'},message:${commitres.commit
                        .message},date:${commitres.commit.date},hash:${commitres.commit.commit}`;
                }
                message = message.replace(/"/g, '');
                message = message.replace(/'/g, '');
                message = message.replace(/\s/g, '');
            }
            const buildres = await build.init(program.env, message);
            if (buildres.status) {
                const start = await gitstart.init(program.env);
                if (start.status) {
                    const commit = new CommitControl();
                    const commitres = await commit.init(
                        !program.autopatch || program.autopatch === 'false' ? false : true
                    );
                    let message = '';
                    if (program.show) {
                        if (program.message === 'commit') {
                            message = `message:${commitres.commit.message},date:${commitres.commit
                                .date},hash:${commitres.commit.commit}`;
                        } else {
                            message = `version:${commitres.version ? commitres.version : '获取版本号失败'},message:${commitres
                                .commit.message},date:${commitres.commit.date},hash:${commitres.commit.commit}`;
                        }
                        message = message.replace(/"/g, '');
                        message = message.replace(/'/g, '');
                        message = message.replace(/\s/g, '');
                    }
                    const end = await gitend.init(
                        program.env,
                        program.open === 'false' || !program.open ? false : true
                    );
                    if(end.status){
                        const uploader = await upload.init(program.env);
                    }
                }
            }
        };
        run();
    }
}
