import { PathTool } from './../utils/path.tool';
import { FileTool } from './../utils/file.tool';
import { ExecTool } from '../utils/exec.tool';
import { RemoveHelperService } from './remove-helper.service';
import replace from 'replace-in-file';
import colors from 'colors';

export class BuildHelperService {
    private buildFile: FileTool = new FileTool();
    private pathTool: PathTool = new PathTool();
    private installCrossEnv: ExecTool = new ExecTool(`npm install cross-env --save`);
    private removeEnvFileTool: RemoveHelperService = new RemoveHelperService(`.env.production`);
    private removePushFileTool: RemoveHelperService = new RemoveHelperService(`./push`,this.pathTool.createPath());
    public createEnvFile(env: string): Promise<any> {
        return new Promise(async (resolve) => {
            const create = await this.buildFile.write(
                `${this.pathTool.createPath()}/.env.production`,
                `REACT_APP_ENV=${env}`
            );
            resolve(create);
        });
    }
    public checkCrossEnv(cdn: any): Promise<any> {
        return new Promise(async (resolve) => {
            const config = await this.buildFile.read(`${this.pathTool.createPath()}/package.json`);
            if (!config.status) {
                resolve({ status: false });
            } else {
                if (!config.data.scripts[`cross-env`]) {
                    const install = await this.installCrossEnv.run();
                    if (!install.status) {
                        resolve({ status: false });
                        return null;
                    }
                }
                const newconfig = await this.buildFile.read(`${this.pathTool.createPath()}/package.json`);
                if (!newconfig.status) {
                    resolve(newconfig);
                } else {
                    newconfig.data.scripts[`cross-env`] = `cross-env PUBLIC_URL=${this.createPublicUrl(
                        cdn
                    )} node scripts/build.js`;
                    const writepackge = await this.buildFile.write(
                        `${this.pathTool.createPath()}/package.json`,
                        config
                    );
                    if (!writepackge.status) {
                        resolve({ status: false });
                    } else {
                        resolve({ status: true });
                    }
                }
            }
        });
    }
    public removeEnvFile(): Promise<any> {
        return new Promise(async (resolve) => {
            const rmove = await this.removeEnvFileTool.remove();
            resolve(rmove);
        });
    }
    public addIndexMessage(message: string): Promise<any> {
        return new Promise(async (resolev) => {
            const add = await replace({
                files: [ `${this.pathTool.createPath()}/build/index.html` ],
                from: (file: any) => new RegExp('</head>', 'g'),
                to: `<script>console.log('${message ? message : '添加调试信息失败'}')</script></head>`
            });
            resolev({
                status: true
            });
        });
    }
    public checkCdn(env: string): Promise<any> {
        return new Promise(async (resolve) => {
            const config = await this.buildFile.read(`${this.pathTool.createPath()}/cdn.helper.json`);
            if (!config.status) {
                resolve({ status: false });
            } else {
                if (!config.data[env]) {
                    resolve({ status: false });
                } else {
                    const zones = [ 'z0', 'z1', 'z2', 'na0', 'as0' ];
                    if (config.data[env].zone) {
                        if (zones.indexOf(config.data[env].zone) === -1) {
                            console.log(
                                colors.yellow(`cdn配置项中zone值 ${config.data[env].zone} 不合法，暂时只支持 ${zones.join('，')}`)
                            );
                            config.data[env].zone = null;
                        }
                    }
                    resolve({
                        status:
                            config.data[env].url && config.data[env].ak && config.data[env].sk && config.data[env].bk
                                ? true
                                : false,
                        data: config.data[env]
                    });
                }
            }
        });
    }
    public checkGithub(env: string): Promise<any> {
        return new Promise(async (resolve) => {
            const config = await this.buildFile.read(`${this.pathTool.createPath()}/github.helper.json`);
            if (!config.status) {
                resolve({ status: false });
            } else {
                if (!config.data[env]) {
                    resolve({ status: false });
                } else {
                    resolve({
                        status: config.data[env].remote && config.data[env].branch ? true : false,
                        data: config.data[env]
                    });
                }
            }
        });
    }
    public clonePushGit(url: string, branch: string): Promise<any> {
        return new Promise(async (resolve) => {
            const cloneExec = new ExecTool(`git clone ${url} push -b ${branch}`);
            const clone = await cloneExec.run();
            resolve(clone);
        });
    }
    public cleanPush(path: string, folder?: string): Promise<any> {
        return new Promise(async (resolve) => {
            const cleanExec = new ExecTool(
                folder ? `rm -rf ./${folder}` : `find ./push -name "*.js" -o -name "*.css" -o -name "*.html"`,
                path
            );
            const clean = await cleanExec.run();
            resolve(clean);
        });
    }
    public copyPush(folder?: string): Promise<any> {
        /* 由于git操作切到了push目录，复制类操作需要切回到项目根目录 */
        return new Promise(async (resolve) => {
            const copyExec = new ExecTool(
                folder ? `cp -rf ./build ./push/${folder}/` : `cp -rf ./build ./push/`,
                this.pathTool.createPath('../')
            );
            const copy = await copyExec.run();
            resolve(copy);
        });
    }
    public addPush(path: string): Promise<any> {
        return new Promise(async (resolve) => {
            const addExec = new ExecTool(`git add -A`, path);
            const add = await addExec.run();
            resolve(add);
        });
    }
    public ignorePush(ignores: any[]): Promise<any> {
        return new Promise(async (resolve) => {
            let ignore = ``;
            ignores.forEach((item) => {
                ignore = `${ignore},${item}`;
            });
            if (ignore) {
                const addIgnore = await this.buildFile.write(`${this.pathTool.createPath()}/push/.gitignore`, ignore);
                resolve(addIgnore);
            } else {
                resolve({ status: true });
            }
        });
    }
    public commitPush(path: string, message?: string): Promise<any> {
        return new Promise(async (resolve) => {
            const commitExec = new ExecTool(`git commit -m "${message ? message : JSON.stringify(new Date())}"`, path);
            const commit = await commitExec.run();
            resolve(commit);
        });
    }
    public donePush(path: string, branch: string): Promise<any> {
        return new Promise(async (resolve) => {
            const doneExec = new ExecTool(`git push origin ${branch}`, path);
            const done = await doneExec.run();
            resolve(done);
        });
    }
    public removePush(): Promise<any> {
        return new Promise(async (resolve) => {
            const remove = await this.removePushFileTool.remove();
            resolve(remove);
        });
    }
    public createPublicUrl(cdn: any) {
        let url = cdn.url ? cdn.url : './';
        if (cdn.dirname) {
            url = url + `${cdn.dirname}/`;
        }
        if (cdn.v) {
            url = url + `${cdn.v}/`;
        }
        return url;
    }
}
