import colors from 'colors';
import shell from 'shelljs';

export class ExecTool {
    private order: string = '';
    private path: string = '';
    constructor(order: string, path?: string) {
        this.order = order;
        if (path) {
            this.path = path;
        }
    }
    public run(): Promise<any> {
        return new Promise((resolve, reject) => {
            if (!this.order) {
                console.log(colors.red(`执行命令不能为空！`));
                resolve({
                    status: false
                });
            } else {
                if (this.path) {
                    shell.cd(this.path);
                    console.log(`执行路径 ${this.path}`.cyan);
                }
                console.log(colors.yellow(`开始执行 ${this.order} 命令`));
                const exec = shell.exec(this.order, { async: true }, (code: number, stdout: any, stderr: any) => {
                    if (code === 0) {
                        console.log(colors.green(`命令 ${this.order} 执行完成`));
                        console.log(``);
                        let data = stdout;
                        try {
                            data = JSON.parse(stdout)[0];
                        } catch (error) {}
                        resolve({
                            status: true,
                            data: data
                        });
                    } else {
                        console.log(colors.red(`执行 ${this.order} 任务出错， 错误码: ${code}`));
                        console.log(``);
                        resolve({
                            status: false
                        });
                    }
                });
                exec.stdout.on('data', (data: any) => {
                    /* shelljs会自动输入执行内容 */
                    // console.log(colors_1.default.white(data));
                });
                exec.stderr.on('data', (error: any) => {
                    /* shelljs会自动输入执行内容 */
                    // console.log(colors.yellow(error));
                });
            }
        });
    }
}
