import fs from 'fs';
import colors from 'colors';
import { ifError } from 'assert';

export class FileTool {
    public read(filepath: string): Promise<any> {
        return new Promise((resolve) => {
            console.log(colors.yellow(`开始读取 ${filepath} 文件`));
            fs.readFile(filepath, (err, data) => {
                if (err) {
                    console.log(colors.red(`读取 ${filepath} 文件失败`));
                    resolve({
                        status: false,
                        data: err
                    });
                } else {
                    console.log(colors.green(`读取 ${filepath} 文件完毕`));
                    resolve({
                        status: true,
                        data: this.reduceData(data, true)
                    });
                }
            });
        });
    }
    public write(filepath: string, data: any): Promise<any> {
        return new Promise((resolve) => {
            console.log(colors.yellow(`开始写入 ${filepath} 文件`));
            fs.writeFile(filepath, this.reduceData(data), (err) => {
                if (err) {
                    console.log(colors.red(`写入 ${filepath} 文件失败`));
                    console.log(``)
                    resolve({
                        status: false
                    });
                } else {
                    console.log(colors.green(`写入 ${filepath} 文件完毕`));
                    console.log(``)
                    resolve({
                        status: true,
                        data: this.reduceData(data)
                    });
                }
            });
        });
    }
    private reduceData(data: any, isRead?: boolean) {
        let value = data;
        if (!isRead) {
            try {
                if(typeof data  !== 'string'){
                    value = JSON.stringify(data);
                }
            } catch (error) {
                value = data;
            }
        }
        if (isRead) {
            try {
                value = JSON.parse(data);
            } catch (error) {
                value = data;
            }
        }
        return value;
    }
}
